import React from 'react';
import { ThemeProvider, styled, createTheme } from '@mui/material/styles';

import {
    Container, IconButton, Divider,
    Typography, List, Toolbar, Box, CssBaseline, useMediaQuery as Size,
} from '@mui/material'

import {
    Fullscreen as FullscreenIcon,
    Menu as MenuIcon,
} from '@mui/icons-material'

// import Logo from '../Images/logo.png';
import Logo from '../Images/evaluacion.jpeg';

import { Outlet } from "react-router-dom";
import { MenuMovil } from '../Components/Navigation/MenuMovil';
import Footer from "../Components/Footer";

// import { psicotheme } from '../Utils/theme'
import { Drawer as MuiDrawer, AppBar as MuiAppBar } from "../Components/Navigation/AppBar"
import { MainListItems, SecondaryListItems } from '../Components/Navigation/listItems';
import { UserOptions } from '../Components/Navigation/UserOptions'

const drawerWidth = 240;
const mdTheme = createTheme();

const AppBar = styled(MuiAppBar, {
    shouldForwardProp: (prop) => prop !== 'open',
})(({ theme, open }) => ({
    zIndex: theme.zIndex.drawer + 1,
    transition: theme.transitions.create(['width', 'margin'], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen,
    }),
    ...(open && {
        marginLeft: drawerWidth,
        width: `calc(100% - ${drawerWidth}px)`,
        transition: theme.transitions.create(['width', 'margin'], {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.enteringScreen,
        }),
    }),
}));


const Drawer = styled(MuiDrawer, 
    { shouldForwardProp: (prop) => prop !== 'open' })(
    ({ theme, open }) => ({
        '& .MuiDrawer-paper': {
            position: 'relative',
            whiteSpace: 'nowrap',
            width: drawerWidth,
            transition: theme.transitions.create('width', {
                easing: theme.transitions.easing.sharp,
                duration: theme.transitions.duration.enteringScreen,
            }),
            boxSizing: 'border-box',
            ...(!open && {
                overflowX: 'hidden',
                transition: theme.transitions.create('width', {
                    easing: theme.transitions.easing.sharp,
                    duration: theme.transitions.duration.leavingScreen,
                }),
                width: theme.spacing(7),
                [theme.breakpoints.up('sm')]: {
                    width: theme.spacing(9),
                },
            }),
        },
    }),
);


function DashboardContent() {

    const [open, setOpen] = React.useState(false);

    const isMovil = Size('(min-width:770px)');
    const navbar = React.useRef(null);

    const toggleDrawer = () => {
        setOpen(!open);
    }

    const [anchorElMovil, setAnchorElMov] = React.useState(false);
    const MenuResponsive = () => {
        console.log(anchorElMovil)
        setAnchorElMov(!anchorElMovil);
    }


    return (
        <ThemeProvider theme={mdTheme}>

            <MenuMovil anchor={anchorElMovil} control={setAnchorElMov} />

            <Box sx={{ display: 'flex' }}>
                <AppBar style={{ backgroundColor: '#fff', boxShadow: 'None' }} position="absolute" open={open}>
                    <Toolbar sx={{ pr: '24px', borderBottom: "1px solid #ec5e69" }} >

                        <IconButton
                            edge="start"
                            color="inherit"
                            aria-label="open drawer"
                            onClick={toggleDrawer}
                            sx={{ marginRight: '36px', ...( open && { display: 'none' }), }} >
                            <MenuIcon style={{
                                background: '#ec5e69',
                                fontSize: "40",
                                color: "#fff"
                            }} />
                        </IconButton>

                        <Typography component="h1" variant="h6" color="inherit" noWrap sx={{ flexGrow: 1 }} >
                            {
                                open ? (
                                    <React.Fragment>

                                        <IconButton onClick={toggleDrawer}>
                                            <MenuIcon />
                                        </IconButton>

                                        <IconButton onClick={(event) => event.target.requestFullscreen()}>
                                            <FullscreenIcon style={{ paddinLeft: 15 }} />
                                        </IconButton>
                                    </React.Fragment>
                                ) : undefined
                            }
                        </Typography>
                        <UserOptions/>
                    </Toolbar>
                </AppBar>
                <Drawer variant="permanent" open={open} >
                    <Toolbar
                        sx={{
                            display: 'flex',
                            alignItems: 'center',
                            justifyContent: 'flex-start',
                            px: [1]
                        }} >
                        <div style={{ flat: 'righ' }} className="sidebar-header">
                            <div className="width_img">
                                <img src={Logo} alt="pruebas psicometricas" />
                            </div>
                        </div>
                    </Toolbar>
                    <Divider />
                    <List>
                        <MainListItems AppBarVisible={open} setAppBarVisible={setOpen} />
                    </List>
                    <Divider />
                    <List>
                        {SecondaryListItems}
                    </List>
                </Drawer>
                <Container maxWidth="lg" sx={{ mt: 2, mb: 2 }}>
                    <Outlet />
                    <Footer />
                </Container>
            </Box>
        </ThemeProvider>
    );
}

export function Dashboard() {
    return <DashboardContent />;
}

